==> hyades.source_3.2.0_20041101_1032.zip: org/eclipse/hyades/test/ui/launch/configurations/TestComponentLaunchConfigurationFacade.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.configurations;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchConfigurationType;
import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.hyades.models.common.testprofile.TPFTestComponent;

/**
 * This class provides a Facade for getting/setting properties specific to a Single-Test
 * Launch Configuration.
 * @author jcanches
 */
public class TestComponentLaunchConfigurationFacade extends AbstractLaunchConfigurationFacade {
	
	public final static String LAUNCH_CONFIGURATION_TYPE =  "org.eclipse.hyades.test.ui.launch.basicTestComponent"; //$NON-NLS-1$
	
	public static ILaunchConfigurationType getLaunchConfigurationType() {
		return DebugPlugin.getDefault().getLaunchManager().getLaunchConfigurationType(LAUNCH_CONFIGURATION_TYPE);
	}
	
	private final static String PROPERTY_TEST_COMPONENT = PROPERTY_PREFIX + ".testComponent"; //$NON-NLS-1$
	
	/**
	 * Retrieves the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 * @deprecated
	 * @see TestComponentLaunchConfigurationFacade#getTestComponent(ILaunchConfiguration, ResourceSet)
	 */
	public static TPFTestComponent getTestComponent(ILaunchConfiguration configuration) throws CoreException {
		EObject eObject = resolveEMFReference(configuration, PROPERTY_TEST_COMPONENT);
		if (eObject != null && eObject instanceof TPFTestComponent) {
			return (TPFTestComponent)eObject;
		}
		return null;
	}
	
	/**
	 * Retrieves the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 * @param configuration
	 * @param resourceSet
	 * @since 3.1
	 */
	public static TPFTestComponent getTestComponent(ILaunchConfiguration configuration, ResourceSet resourceSet) throws CoreException {
		EObject eObject = resolveEMFReference(configuration, PROPERTY_TEST_COMPONENT, resourceSet);
		if (eObject != null && eObject instanceof TPFTestComponent) {
			return (TPFTestComponent)eObject;
		}
		return null;
	}
	
	/**
	 * Sets the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 */	
	public static void setTestComponent(ILaunchConfigurationWorkingCopy configuration, TPFTestComponent testComponent) {
		storeEMFReference(configuration, PROPERTY_TEST_COMPONENT, testComponent);
	}
	
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/test/ui/launch/configurations/TestComponentLaunchConfigurationFacade.java <==
/*******************************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: TestComponentLaunchConfigurationFacade.java,v 1.5 2005/02/16 22:22:13 qiyanli Exp $
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.ui.launch.configurations;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.debug.core.DebugPlugin;
import org.eclipse.debug.core.ILaunchConfiguration;
import org.eclipse.debug.core.ILaunchConfigurationType;
import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.hyades.models.common.testprofile.TPFTestComponent;

/**
 * This class provides a Facade for getting/setting properties specific to a Single-Test
 * Launch Configuration.
 * @author jcanches
 */
public class TestComponentLaunchConfigurationFacade extends AbstractLaunchConfigurationFacade {
	
	public final static String LAUNCH_CONFIGURATION_TYPE =  "org.eclipse.hyades.test.ui.launch.basicTestComponent"; //$NON-NLS-1$
	
	public static ILaunchConfigurationType getLaunchConfigurationType() {
		return DebugPlugin.getDefault().getLaunchManager().getLaunchConfigurationType(LAUNCH_CONFIGURATION_TYPE);
	}
	
	private final static String PROPERTY_TEST_COMPONENT = PROPERTY_PREFIX + ".testComponent"; //$NON-NLS-1$
	
	/**
	 * Retrieves the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 * @deprecated
	 * @see TestComponentLaunchConfigurationFacade#getTestComponent(ILaunchConfiguration, ResourceSet)
	 */
	public synchronized static TPFTestComponent getTestComponent(ILaunchConfiguration configuration) throws CoreException {
		EObject eObject = resolveEMFReference(configuration, PROPERTY_TEST_COMPONENT);
		if (eObject != null && eObject instanceof TPFTestComponent) {
			return (TPFTestComponent)eObject;
		}
		return null;
	}
	
	/**
	 * Retrieves the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 * @param configuration
	 * @param resourceSet
	 * @since 3.1
	 */
	public synchronized static TPFTestComponent getTestComponent(ILaunchConfiguration configuration, ResourceSet resourceSet) throws CoreException {
		EObject eObject = resolveEMFReference(configuration, PROPERTY_TEST_COMPONENT, resourceSet);
		if (eObject != null && eObject instanceof TPFTestComponent) {
			return (TPFTestComponent)eObject;
		}
		return null;
	}
	
	/**
	 * Sets the TestComponent property of a Hyades Launch Configuration. This property defines
	 * which Test Component will be run by the Launch Configuration.
	 */	
	public synchronized static void setTestComponent(ILaunchConfigurationWorkingCopy configuration, TPFTestComponent testComponent) {
		storeEMFReference(configuration, PROPERTY_TEST_COMPONENT, testComponent);
	}
	
}
